@@ -6,10 +6,10 @@ import java.util.List;
 
 import org.gcube.portlets.user.gisviewer.client.Constants;
 import org.gcube.portlets.user.gisviewer.client.GisViewerPanel;
-import org.gcube.portlets.user.gisviewer.client.commons.beans.BoundsMap;
 import org.gcube.portlets.user.gisviewer.client.commons.beans.GisViewerBaseLayerInterface;
 import org.gcube.portlets.user.gisviewer.client.commons.beans.LayerItem;
 import org.gcube.portlets.user.gisviewer.client.commons.beans.MapViewInfo;
+import org.gcube.portlets.user.gisviewer.client.commons.beans.TransectParameters;
 import org.gwtopenmaps.openlayers.client.Bounds;
 import org.gwtopenmaps.openlayers.client.LonLat;
 import org.gwtopenmaps.openlayers.client.Map;
@@ -21,11 +21,11 @@ import org.gwtopenmaps.openlayers.client.control.DrawFeature;
 import org.gwtopenmaps.openlayers.client.control.DrawFeature.FeatureAddedListener;
 import org.gwtopenmaps.openlayers.client.control.DrawFeatureOptions;
 import org.gwtopenmaps.openlayers.client.control.LayerSwitcher;
+import org.gwtopenmaps.openlayers.client.control.MouseDefaults;
 import org.gwtopenmaps.openlayers.client.control.MousePosition;
 import org.gwtopenmaps.openlayers.client.control.MousePositionOptions;
 import org.gwtopenmaps.openlayers.client.control.MousePositionOutput;
 import org.gwtopenmaps.openlayers.client.control.NavToolbar;
-import org.gwtopenmaps.openlayers.client.control.Navigation;
 import org.gwtopenmaps.openlayers.client.control.PanZoomBar;
 import org.gwtopenmaps.openlayers.client.control.ZoomBox;
 import org.gwtopenmaps.openlayers.client.event.MapClickListener;
@@ -46,6 +46,7 @@ import org.gwtopenmaps.openlayers.client.util.JSObject;
 import com.extjs.gxt.ui.client.widget.ContentPanel;
 import com.extjs.gxt.ui.client.widget.layout.FitLayout;
 import com.google.gwt.core.shared.GWT;
+import com.google.gwt.user.client.Element;
 import com.google.gwt.user.client.Window;
 import com.google.gwt.user.client.ui.DockPanel;
 import com.google.gwt.user.client.ui.Widget;
@@ -55,20 +56,13 @@ public class OpenLayersMap {
 	protected static final int MAX_ZINDEX = 280;
 	private List<LayerItem> layerItems = new ArrayList<LayerItem>();
 	private Map map;
-	private ContentPanel cpMapWidget;
-	/**
-	 * @return the map
-	 */
-	public Map getMap() {
-		return map;
-	}
 
 	private MapWidget mapWidget;
 	private HashMap<String, String> mapping = new HashMap<String, String>();
 	private HashMap<LayerItem, Layer> mappingLayerItemsToLayers = new HashMap<LayerItem, Layer>();
 	private HashMap<Layer, LayerItem> mappingLayersToLayerItems = new HashMap<Layer, LayerItem>();
 	private NavToolbar mouseToolBar;
-	private Navigation navigation;
+	private MouseDefaults mouseDefaults;
 	//private OverviewMap overViewMap;
 	//private MouseClickOnMap mouseClickOnMap;
 //	private ToolBarPanelOld toolBarPanel;
@@ -80,8 +74,8 @@ public class OpenLayersMap {
 	private String tableTransect = "";
 	private String fieldTransect = "";
 	private VectorFeature prevVf;
+	public static Bounds defaultBounds = new Bounds(-180, -90, 180, 90);// -180, -90, 180, 90 //-20037508.34,-20037508.34,20037508.34,20037508.34);// TODO -180, -90, 180, 90);
 	private List<Layer> baseLayers = new ArrayList<Layer>();
-	private String transectUrl;
 	//private static String defaultProjection = "EPSG:900913";//"EPSG:4326";
 	private DrawFeature drawBoxControl;
 	private DrawFeature drawLineControl;
@@ -89,6 +83,7 @@ public class OpenLayersMap {
 	private int maxZindex = 0;
 	private ToolBarPanel toolBarPanel;
 	private List<GisViewerBaseLayerInterface> baseLayersIntefaces;
+	private TransectParameters transect;
 	
 	//ADDED BY FRANCESCO M. TO FIX # support 832
 	public class ZIndexBaseGisViewer extends ZIndexBase{
@@ -122,7 +117,8 @@ public class OpenLayersMap {
 		}
 	}
 	// constructor
-	public OpenLayersMap(String w, String h, int numZoomLevels, String title, final OpenLayersHandler handler) {
+	public OpenLayersMap(String w, String h, int numZoomLevels, // projection, transectUrl removed
+			String title, final OpenLayersHandler handler) {
 
 		this.handler = handler;
 		this.numZoomLevels = numZoomLevels;
@@ -133,17 +129,18 @@ public class OpenLayersMap {
 		mapOptions.setControls(new JObjectArray(new JSObject[] {}));
 		mapOptions.setNumZoomLevels(numZoomLevels);
 		mapOptions.setProjection(Constants.defaultProjection);
-		mapOptions.setZIndexBase(new ZIndexBaseGisViewer());
-//		mapOptions.getJSObject().setProperty("displayProjection", Constants.defaultProjection);
-
 		
+		mapOptions.setZIndexBase(new ZIndexBaseGisViewer());
+		
+
 		// let's create map widget and map objects
 		mapWidget = new MapWidget(w, h, mapOptions); // map widget
 		map = mapWidget.getMap(); // map js-mapped object		
 		mapWidget.setTitle(title); // set title
-		map.setMaxExtent(Constants.defaultBounds);
-//		map.setMinMaxZoomLevel(Constants.defaultOpenLayersMapDefaultZoom, numZoomLevels);
-		
+		map.setMaxExtent(defaultBounds);
+
+		//map.getJSObject().setProperty("allOverlays", true);
+
 		// set click listener on the map
 		map.addMapClickListener(new MapClickListener() {
 			public void onClick(MapClickEvent mapClickEvent) {
@@ -177,19 +174,16 @@ public class OpenLayersMap {
 		});
 
 		// set the other controls
-		navigation = new Navigation();
+		mouseDefaults = new MouseDefaults();
 		mouseToolBar = new NavToolbar();
 		PanZoomBar pamZoomBar = new PanZoomBar();
 		zoomBox = new ZoomBox();
 
-		
-		//ACTIVE THIS IF USE MOUSEDEFAULTS CONTROL - ONLY OPENLAYERS <= 2.12
-		/*
-		Element e = navigation.getJSObject().getPropertyAsDomElement("position");
+		Element e = mouseDefaults.getJSObject().getPropertyAsDomElement("position");
 		e.setPropertyDouble("x", -300);
-		navigation.getJSObject().setProperty("position", e);
-		*/
+		mouseDefaults.getJSObject().setProperty("position", e);
 
+	
 		VectorOptions vectoroptions = new VectorOptions();
 		vectoroptions.setDisplayInLayerSwitcher(false);
 		vectoroptions.setDisplayOutsideMaxExtent(true);
@@ -197,7 +191,7 @@ public class OpenLayersMap {
 		vectorLayer = new Vector("transet", vectoroptions);
 		map.addLayer(vectorLayer);
 		vectorLayer.setZIndex(MAX_ZINDEX);
-
+		
 //		addBaseLayers();
 
 		String wmsURI = GisViewerPanel.resources.baseLayer().getText();
@@ -205,7 +199,7 @@ public class OpenLayersMap {
 		String[] params = wmsURI.split("\\?");
 		
 		if(params.length<2){
-			Constants.info("","ERROR: No base layer found!");
+			GWT.log("ERROR: No base layer found!");
 		}
 		
 		String baseLayerURI = params[0];
@@ -221,12 +215,13 @@ public class OpenLayersMap {
 		}
 		
 		if(baseLayerURI==null || baseLayerURI.isEmpty() || baseLayerName.isEmpty()){
-			Window.alert("ERROR: No base layer found!");
+			GWT.log("ERROR: No base layer found!");
 		}
 			
+		
 		addBaseLayerToOpenLayerMap("True Marble", baseLayerName, baseLayerURI);
-
-		addControl(navigation);
+		
+		addControl(mouseDefaults);
 		addControl(pamZoomBar);
 		addControl(getMousePosition());
 		addControl(zoomBox);
@@ -242,7 +237,9 @@ public class OpenLayersMap {
 	private void addTransectControl() {
 		FeatureAddedListener listener = new FeatureAddedListener() {
 			public void onFeatureAdded(VectorFeature vf) {
-				if (transectUrl==null)
+				
+				GWT.log("Transect "+transect);
+				if (transect.getUrl()==null)
 					return;
 				org.gwtopenmaps.openlayers.client.geometry.LineString line = org.gwtopenmaps.openlayers.client.geometry.LineString
 						.narrowToLineString(vf.getGeometry().getJSObject());
@@ -259,12 +256,13 @@ public class OpenLayersMap {
 					y1 = coordinate[0][1];
 					x2 = coordinate[1][0];
 					y2 = coordinate[1][1];
-					String url = transectUrl + "?"
+					String url = transect.getUrl() + "?"
 							+ "x1=" + x1 + "&" + "y1=" + y1 + "&" + "x2=" + x2
 							+ "&" + "y2=" + y2 + "&SRID=4326"
 							+ "&maxelements=1000" + "&minimumgap=-1"
 							+ "&tablename=" + getTableTransect()
-							+ "&biodiversityfield=" + getFieldTransect();
+							+ "&biodiversityfield=" + getFieldTransect()+""
+							+ "&scope="+transect.getScope();
 
 					Window.open(url, "_blank", "");
 
@@ -307,6 +305,7 @@ public class OpenLayersMap {
 			}
 		};
 		
+		/*
 		DrawFeatureOptions options = new DrawFeatureOptions();
 		options.onFeatureAdded(listener);
 		RegularPolygonHandlerOptions handlerOptions = new RegularPolygonHandlerOptions();
@@ -315,6 +314,18 @@ public class OpenLayersMap {
 		options.setHandlerOptions(handlerOptions);
 		drawBoxControl = new DrawFeature(vectorLayer, new RegularPolygonHandler(), options);
 		this.map.addControl(drawBoxControl);
+		*/
+		
+		//CHANGED BY FRANCESCO
+		DrawFeatureOptions options = new DrawFeatureOptions();
+		options.onFeatureAdded(listener);
+		final RegularPolygonHandlerOptions boxHandlerOptions = new RegularPolygonHandlerOptions();
+	    boxHandlerOptions.setIrregular(true);
+	    boxHandlerOptions.setSides(4);
+	    RegularPolygonHandler boxHandler = new RegularPolygonHandler();
+	    drawBoxControl = new DrawFeature(vectorLayer, boxHandler, options);
+	    ((RegularPolygonHandler) drawBoxControl.getHandler()).setOptions(boxHandlerOptions);
+		this.map.addControl(drawBoxControl);
 	}
 
 	/**
@@ -386,10 +397,26 @@ public class OpenLayersMap {
 		}
 
 		map.addLayers(layers);
+		//vectorLayer.setZIndex(MAX_ZINDEX);
+		
+		// OverviewMapOptions overOptions = new OverviewMapOptions();
+		// Layer[] ls = new Layer[1];
+		// ls[0] = layers[0];
+		//
+		// overOptions.setLayers(ls);
+		//
+		// if (Constants.isOverViewMapVisible) {
+		// overViewMap = new OverviewMap();
+		// addControl(overViewMap);
+		// }
 	}
 
+//	public void addToolBarOld(ToolBarPanelOld toolBarPanel) {
+//		this.toolBarPanel = toolBarPanel;
+//	}
+//
 	/**
-	 * @param toolBarPanel
+	 * @param toolBarPanel2
 	 */
 	public void addToolBar(ToolBarPanel toolBarPanel) {
 		this.toolBarPanel = toolBarPanel;
@@ -406,8 +433,8 @@ public class OpenLayersMap {
 	public Widget getDockPanel() {
 		// int zoom=map.getZoomForExtent(map.getMaxExtent(), true);
 		// let's center the map to somewhere and set zoom level to 5
-		/*LonLat center = new LonLat(0, 0);
-		map.setCenter(center, Constants.openLayersMapDefaultZoom);*/
+		LonLat center = new LonLat(0, 0);
+		map.setCenter(center, Constants.openLayersMapDefaultZoom);
 		// map.setCenter(center, zoom);
 
 		// eventually add the map widget to div:map
@@ -423,19 +450,19 @@ public class OpenLayersMap {
 	}
 
 	public ContentPanel getContentPanel() {
-		cpMapWidget = new ContentPanel();
-		cpMapWidget.setHeaderVisible(false);
-		cpMapWidget.setLayout(new FitLayout());
-		cpMapWidget.add(mapWidget);
-		cpMapWidget.setTopComponent(toolBarPanel);
+		ContentPanel panel = new ContentPanel();
+		panel.setHeaderVisible(false);
+		panel.setLayout(new FitLayout());
+		panel.add(mapWidget);
+		panel.setTopComponent(toolBarPanel);
 		
+		// int zoom=map.getZoomForExtent(map.getMaxExtent(), true);
+		// let's center the map to somewhere and set zoom level to 5
 		LonLat center = new LonLat(0, 0);
-		map.setCenter(center,Constants.defaultOpenLayersMapDefaultZoom);
+		map.setCenter(center, Constants.openLayersMapDefaultZoom);
+		// map.setCenter(center, zoom);
 
-//		Constants.info("getContentPanel", "getZoomForExtent: "+map.getZoom());
-//		Constants.info("minZoomLevel", ": "+map.getJSObject().getProperty("minZoomLevel"));
-		
-		return cpMapWidget;
+		return panel;
 	}
 
 	public void setOpacity(LayerItem layerItem, double opacity) {
@@ -465,21 +492,8 @@ public class OpenLayersMap {
 	}
 
 	public void zoomToMaxExtent() {
-		//TO FIX BUG ON MAX EXTENT OPENLAYES 2.13.1
-		this.map.zoomTo(Constants.defaultOpenLayersMapDefaultZoom);
-		this.map.setCenter(new LonLat(0, 0));
-		
-//		this.map.zoomToMaxExtent();
+		this.map.zoomToMaxExtent();
 	}
-	
-	/*
-	public void centerMap(int zoom){
-		this.map.setCenter(new LonLat(0, 0), zoom);
-	}
-	
-	public void centerMapCurrentZoom(){
-		this.map.setCenter(new LonLat(0, 0), map.getZoom());
-	}*/
 
 	public String getProjection() {
 		return this.map.getProjection();
@@ -521,9 +535,9 @@ public class OpenLayersMap {
 
 	public void activatePan(boolean isActivate) {
 		if (isActivate)
-			navigation.activate();
+			mouseDefaults.activate();
 		else
-			navigation.deactivate();
+			mouseDefaults.deactivate();
 	}
 
 	// added by gianpaolo coro in 13-07-11 for returning to cache when
@@ -598,35 +612,19 @@ public class OpenLayersMap {
 		return fieldTransect;
 	}
 
-	public void changeSize(int w, int h) {
+	public void changeSize(String w, String h) {
 		// if together are positives
-		
-		
-		if (w > 0 && h > 0) {
-			
-			String width = Integer.toString(w-Constants.mapPanelSpacingX);
-			String heigth = Integer.toString(h-Constants.mapPanelSpacingY);
-			Constants.info("changeSize", "New width: "+width +" new heigth: "+heigth);
-			if(Integer.parseInt(width) > 0 && Integer.parseInt(heigth)>0){
-				
-//				if(Integer.parseInt(width)>1000)
-//					width = "1000";
-//				
-				mapWidget.setWidth(width+"px");
-				mapWidget.setHeight(heigth+"px");
-				this.updateSize();
-			}
-
+		if (Integer.parseInt(w) > 0 && Integer.parseInt(h) > 0) {
+			mapWidget.setWidth(w);
+			mapWidget.setHeight(h);
+			this.updateSize();
 		}
+		// mapWidget.setSize(w, h);
 	}
 
 	public void updateSize() {
-		mapWidget.getMap().updateSize();
-//		mapWidget.getMap().setCenter(new LonLat(0, 0));
-//		mapWidget.getMap().zoomToMaxExtent();
-//		Constants.info("\n\nMap updateSize", "(" + getMapWidth() + ","	+ getMapHeight() + ") zoom: "+map.getZoom());
-//		Constants.info("Map updateSize", "Extent: "+ map.getMaxExtent() + ", Resolution:"	+ map.getMaxResolution());
-//		Constants.info("Map updateSize", "getZoomForExtent: "+ map.getZoomForExtent(Constants.defaultBounds, false));
+		map.updateSize();
+		Constants.info("Update size", "(" + getMapWidth() + ","	+ getMapHeight() + ")");
 	}
 
 	public int getMapWidth() {
@@ -707,6 +705,9 @@ public class OpenLayersMap {
 			}
 			GWT.log("layer: "+layerItem.getName()+" setting ZIndex: "+newOrder);
 			layer.setZIndex(newOrder);
+		
+			//OLD COD
+//			layer.setZIndex(maxZindex + (int)layerItem.getOrder());
 		}
 	}
 
@@ -786,8 +787,8 @@ public class OpenLayersMap {
 	/**
 	 * @param result
 	 */
-	public void setTransectUrl(String transectUrl) {
-		this.transectUrl = transectUrl;
+	public void setTransect(TransectParameters transect) {
+		this.transect = transect;
 	}
 
 	public void deactivateDrawBoxControl() {
@@ -827,27 +828,21 @@ public class OpenLayersMap {
 		wmsOptions.setIsBaseLayer(layerItem.isBaseLayer());
 		wmsOptions.setBuffer(2); // from serviceimpl
 		wmsOptions.setWrapDateLine(true); // default
-		
-		BoundsMap maxExtent = layerItem.getMaxExtent();
-		if(maxExtent!=null){
-			GWT.log(layerItem.getName()+", Max extent Map Found: "+maxExtent);
-			wmsOptions.setMaxExtent(new Bounds(maxExtent.getLowerLeftX(), maxExtent.getLowerLeftY(), maxExtent.getUpperRightX(), maxExtent.getUpperRightY()));
-		}else{
-			GWT.log(layerItem.getName()+", Max extent is null settings: "+Constants.defaultBounds);
-			wmsOptions.setMaxExtent(Constants.defaultBounds);
-		}
-		
-		wmsOptions.setProjection(Constants.defaultProjection);
-//		wmsOptions.getJSObject().setProperty("displayProjection", Constants.defaultProjection);
-		
-//		wmsOptions.setDisplayOutsideMaxExtent(false);
 		WMSParams wmsParams = new WMSParams();
 		wmsParams.setLayers(layerItem.getLayer());
-		wmsParams.setTransparent(!layerItem.isBaseLayer());
+		wmsParams.setIsTransparent(!layerItem.isBaseLayer());
 		wmsParams.setFormat("image/png");
-//		wmsParams.setMaxExtent(Constants.defaultBounds);
+		//wmsParams.setMaxExtent(defaultBounds);
+		
 		
 		Layer layer = new WMS(layerItem.getTitle(), layerItem.getGeoserverWmsUrl(), wmsParams, wmsOptions);
+
+
+		//TODO
+
+//		System.out.println("layer.getJSObject().toString() "+layer.getJSObject().createJSObject().toString());
+		
+
 		layer.setDisplayInLayerSwitcher(displayInLayerSwitcher);
 		mappingLayerItemsToLayers.put(layerItem, layer);
 		mappingLayersToLayerItems.put(layer, layerItem);
@@ -888,7 +883,11 @@ public class OpenLayersMap {
 		}
 	}
 	
-	public VectorFeature getDataFeature(){
-		return prevVf;
+		/**
+	 * @return the map
+	 */
+	public Map getMap() {
+		return map;
 	}
+	
 }
